@@ -20,8 +20,9 @@
 #' @export
 read.pts <- function(file="x", na=9999)
 {	
-	pts <- read.table(file,skip=2)
-	rownames(pts) <- pts[,1]
+    pts <- read.table(file,skip=2)
+    
+	try(suppressWarnings(rownames(pts) <- pts[,1]),silent = T)
 	pts <- as.matrix(pts[,2:4])
         nas <- which(pts == na)
         if (length(nas) > 0)
