@@ -12,10 +12,10 @@ RcppExport SEXP ang_calcC(SEXP x_, SEXP y_) {
 
     return wrap(angle);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
 
    
@@ -31,9 +31,9 @@ RcppExport SEXP ang_calcM(SEXP x_, SEXP y_) {
 
     return wrap(angle);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
 
