@@ -15,8 +15,8 @@ RcppExport SEXP barycenterCpp(SEXP vb_, SEXP it_) {
     }
     return wrap(bary);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; // -Wall
 }
