@@ -29,9 +29,9 @@ RcppExport SEXP createL(SEXP Matrix_, SEXP threads_= wrap(1)) {
     K = K+K.t();
     return wrap(K);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
   
