@@ -23,8 +23,8 @@ RcppExport SEXP face_zero(SEXP it_) {
     
     return wrap(out);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
