@@ -29,8 +29,8 @@ RcppExport SEXP fastSubsetMeans(SEXP x_, SEXP inds_, SEXP k_, SEXP threads_) {
 				
     return out;
   }  catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
